@@ -29,24 +29,6 @@ pub fn select(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
     stream.into_token_stream()
 }
 
-#[proc_macro]
-pub fn inline(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
-    let p = parser::Parser::new(input);
-
-    let mut stream = TokenStream::default();
-
-    match p.parse() {
-        Ok(output) => {
-            output.expand_inline(&mut stream, Span::mixed_site());
-        }
-        Err(errors) => {
-            format_errors(errors, &mut stream, Span::mixed_site());
-        }
-    }
-
-    stream.into_token_stream()
-}
-
 fn format_errors(errors: Vec<Error>, stream: &mut TokenStream, span: Span) {
     let start = stream.checkpoint();
     let mut it = errors.into_iter();
